@@ -45,13 +45,4 @@ class SimplePriorityQueue(list):
         heapq.heappush(self, (-priority, len(self), item))
 
 
-if __name__ == '__main__':
-    from random import randint
-
-    queue = SimplePriorityQueue()
-
-    for i in range(100):
-        queue.push_pri('*' * i, randint(1, 1000))
-
-    print(queue)
-    [print(i) for i in queue]
+__all__ = ('SimplePriorityQueue', )
